@@ -30,8 +30,9 @@ from troposphere.ecs import (
     Ulimit,
 )
 
-from ecs_composex.common import LOG, NONALPHANUM, add_parameters
+from ecs_composex.common import NONALPHANUM
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME, Parameter
+from ecs_composex.common.logging import LOG
 from ecs_composex.compose.compose_secrets.services_helpers import map_secrets
 from ecs_composex.compose.compose_services.docker_tools import (
     import_time_values_to_seconds,
@@ -50,6 +51,7 @@ from ecs_composex.ecs.ecs_conditions import (
     USE_WINDOWS_OS_T,
 )
 
+from ...common.troposphere_tools import add_parameters
 from .helpers import extend_container_envvars
 from .service_image import ServiceImage
 
@@ -340,6 +342,22 @@ class ComposeService:
         if self.container_definition:
             setattr(self.container_definition, "Command", new_command)
 
+    @property
+    def entrypoint(self):
+        _entrypoint = set_else_none("entrypoint", self.definition, alt_value=NoValue)
+        if isinstance(_entrypoint, str):
+            return shlex.split(_entrypoint)
+        else:
+            return _entrypoint
+
+    @entrypoint.setter
+    def entrypoint(self, new_entrypoint):
+        if isinstance(new_entrypoint, str):
+            new_entrypoint = shlex.split(new_entrypoint)
+        self.definition.update({"entrypoint": new_entrypoint})
+        if self.container_definition:
+            setattr(self.container_definition, "EntryPoint", new_entrypoint)
+
     @property
     def runtime_architecture(self):
         return set_else_none("CpuArchitecture", self.x_ecs, None)
@@ -900,6 +918,7 @@ class ComposeService:
             Environment=self.cfn_environment,
             LogConfiguration=NoValue,
             Command=self.command,
+            EntryPoint=self.entrypoint,
             HealthCheck=self.ecs_healthcheck,
             DependsOn=NoValue,
             Essential=self.is_essential,
