@@ -22,9 +22,10 @@ from troposphere import AWSHelperFn, GetAtt, NoValue, Ref, Sub
 from troposphere.iam import Policy as IamPolicy
 from troposphere.iam import PolicyType
 
-from ecs_composex.common import LOG, add_parameters, add_update_mapping
 from ecs_composex.common.cfn_params import STACK_ID_SHORT, Parameter
+from ecs_composex.common.logging import LOG
 from ecs_composex.common.stacks import ComposeXStack
+from ecs_composex.common.troposphere_tools import add_parameters, add_update_mapping
 from ecs_composex.compose.compose_services.helpers import extend_container_envvars
 from ecs_composex.iam.import_sam_policies import get_access_types
 from ecs_composex.kms.kms_params import MAPPINGS_KEY as KMS_MAPPING_KEY
@@ -380,18 +381,15 @@ def map_resource_env_vars_to_family_services(
     return_values = (
         {} if not keyisset("ReturnValues", target[-1]) else target[-1]["ReturnValues"]
     )
+    if return_values:
+        env_vars = resource.generate_resource_service_env_vars(target, return_values)
+    else:
+        env_vars = resource.generate_ref_env_var(target)
     for svc in target[2]:
-        if svc in target[0].managed_sidecars:
-            continue
-        if return_values:
-            extend_container_envvars(
-                svc.container_definition,
-                resource.generate_resource_service_env_vars(target, return_values),
-            )
-        else:
-            extend_container_envvars(
-                svc.container_definition, resource.generate_ref_env_var(target)
-            )
+        extend_container_envvars(
+            svc.container_definition,
+            env_vars,
+        )
 
 
 def map_resource_return_value_to_services_command(
